@@ -195,16 +195,13 @@ void YouTube::parseVideoPage() {
 
 QString YouTube::decryptSignature(const QString &s) {
     QString signature;
-    QStringList slist = this->reverseString(s).split("", QString::SkipEmptyParts);
+    QStringList slist = this->reverseString(s.mid(3)).split("", QString::SkipEmptyParts);
 
-    if (slist.size() > 65) {
-        slist.removeFirst();
-        slist.removeFirst();
-
-        QString b = slist.at(0);
-        slist.replace(0, slist.at(65 % slist.size()));
-        slist.replace(65, b);
-        signature = this->reverseString(slist.join(""));
+    if (slist.size() > 60) {
+        QString b = slist.last();
+        slist.replace(slist.size() - 1, slist.at(56 % slist.size()));
+        slist.replace(56, b);
+        signature = slist.join("");
     }
 
     return signature;
